mgkit.plots package
===================

Submodules
----------

.. toctree::

   mgkit.plots.abund
   mgkit.plots.boxplot
   mgkit.plots.colors
   mgkit.plots.heatmap
   mgkit.plots.unused
   mgkit.plots.utils

Module contents
---------------

.. automodule:: mgkit.plots
   :members:
   :undoc-members:
   :show-inheritance:
